@@ -200,7 +200,6 @@ def set_bv_target_column(df,multiplier):
         logger.info('Setting BV status target ')
         df = df[df.BV.notna()]
         df['BV']=df['BV'].astype('float32')
-        df.loc[df['BV']>40,'BV']=50
         df['BV']=df['BV']*multiplier
         date_col = df['campaign_bulk_date']
         df.drop( labels=['campaign_bulk_date'], axis=1, inplace=True )
@@ -406,7 +405,7 @@ def fill_variables(df):
         'DaysSinceFirstContact':0,
         'NumFoundingRounds':0,
         'FundingAmount':0,
-        'DaysSinceLastSeed':999999
+        'DaysSinceLastSeed':9999
     }
 
     for key in variables_dict.keys():        
@@ -414,6 +413,7 @@ def fill_variables(df):
             logger.info(f'Filling variable {key} nulls with {variables_dict[key]}')
             logger.info(df[key].isna().sum())
             df[key] = df[key].fillna(variables_dict[key])
+            logger.info(df[key].value_counts())
         else:
             logger.info(f'{key} not available to fill')
     return df
